[−][src]Struct google_dfareporting3d3::FileList
List of files for a report.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list files (response)
- files list reports (response)
Fields
next_page_token: Option<String>Continuation token used to page through files. To retrieve the next page of results, set the next request's "pageToken" to the value of this field. The page token is only valid for a limited amount of time and should not be persisted.
items: Option<Vec<File>>The files returned in this response.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string "dfareporting#fileList".
etag: Option<String>Etag of this resource.